clear all
set more off
set linesize 80

use golf_data
describe


table reg_cat
regress money_rank reg_cat


generate mid_dummy = 1 if reg_cat == 2
replace mid_dummy = 0 if reg_cat != 2
generate high_dummy = 1 if reg_cat == 3
replace high_dummy = 0 if reg_cat !=3
list name reg_cat mid_dummy high_dummy in 20/40, clean

drop mid_dummy high_dummy

generate mid_dummy = reg_cat == 2
generate high_dummy = reg_cat == 3
table mid_dummy
table high_dummy

tabulate reg_cat, generate(dummy)
list name reg_cat dummy1 dummy2 dummy3 in 20/40, clean

tabstat money_rank, by(reg_cat)
display "The difference between Mid and Low is " round(61.43243 - 91.90476, .01)
display "The difference between High and Low is " round(60.74 - 91.90476, .01)

regress money_rank mid_dummy high_dummy

regress money_rank i.reg_cat

regress money_rank ib3.reg_cat

margins, at(reg_cat = (1 2 3))
*marginsplot, scheme(lean2)

regress money_rank i.reg_cat avg_putts avg_drive

margins, at(reg_cat = (1 2 3) avg_putts = 0 avg_drive = 0)

egen z_putts = std(avg_putts)
egen z_drive = std(avg_drive)

regress money_rank i.reg_cat z_putts z_drive

summarize avg_putts, detail

recode reg_cat (1 = 0) (2 = 1) (3 = 1), gen(reg_cat2)
label define regul2 0 "Low" 1 "High"
label values reg_cat2 regul2
label variable reg_cat2 "Greens in Regulation -- Recoded"

regress money_rank i.reg_cat2 c.z_putts

margins, at(z_putts = (-2(1)2) reg_cat2 = (0 1))
marginsplot, noci scheme(lean2) ///
	legend(order(1 "Low" 2 "High" 3 "y") pos(6) row(1)) ///
	legend(subtitle("Greens in regulation category")) ///
	title("") ytitle("Predicted money rank") ///
	xtitle("Average number of putts - {it:z} score") ///
	addplot((pcarrowi 62 0 92 0) (pcarrowi 92 0 62 0)) ///
	text(89 -0.1 "b{subscript:0}") ///
	text(77 -0.1 "b{subscript:1}") ///
	text(63 -0.2 "b{subscript:0} + b{subscript:1}")
gr_edit .legend.plotregion1.key[3].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.key[4].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[3].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[3].fill_if_undrawn.setstyle, style(no)
gr_edit .legend.plotregion1.label[4].draw_view.setstyle, style(no)
gr_edit .legend.plotregion1.label[4].fill_if_undrawn.setstyle, style(no)
gr_edit .legend.plotregion1.DragBy 0 10

	

regress money_rank i.reg_cat2 c.z_putts i.reg_cat2#c.z_putts	

quietly margins, at(z_putts = (-2(1)2) reg_cat = (0 1))

marginsplot, noci scheme(lean2) ///
	legend(order(1 "Low" 2 "High") pos(6) row(1)) ///
	legend(subtitle("Greens in regulation category")) ///
	title("") ytitle("Predicted money rank") ///
	xtitle("Average number of putts - {it:z} score")  ///
	text(20 0 "y{superscript:'} = b{subscript:0} + b{subscript:1}high_dummy2 + b{subscript:2}z_putts + b{subscript:3}high_dummy2 x z_putts") ///
	text(80 -1.5 "y{superscript:'} = b{subscript:0} + b{subscript:2}z_putts")


*** may want to add to a plot depending on what I do with the chapter
*** 	addplot((scatter money_rank z_putts if reg_cat2 == 1) ///
***		(scatter money_rank z_putts if reg_cat2 == 2)) ///
			
/* twoway lfit money_rank z_putts if reg_cat2 == 1 || ///
	   lfit money_rank z_putts if reg_cat2 == 2 || ///
	   scatter money_rank z_putts if reg_cat2 == 1 || ///
	   scatter money_rank z_putts if reg_cat2 == 2
*/

regress money_rank i.reg_cat2 c.z_putts i.reg_cat2#c.z_putts, coeflegend

lincom _b[_cons] + _b[1.reg_cat2] //intercept -- b0 + b1
lincom _b[z_putts] + _b[1.reg_cat2#c.z_putts] //slope -- b2 + b3

regress money_rank ibn.reg_cat2 ibn.reg_cat2#c.z_putts, nocons

regress money_rank ibn.reg_cat2 ibn.reg_cat2#c.z_putts, nocons coeflegend
lincom  _b[1.reg_cat2] - _b[0bn.reg_cat2] // b1
lincom  _b[1.reg_cat2#c.z_putts] -  _b[0bn.reg_cat2#c.z_putts] // b3

regress money_rank i.reg_cat c.z_putts i.reg_cat#c.z_putts

quietly margins, at(z_putts = (-2(1)2) reg_cat = (1 2 3))
marginsplot, noci scheme(lean2) ///
	legend(pos(6) row(1)) ///
	legend(subtitle("Greens in regulation category")) ///
	title("") ytitle("Predicted money rank") ///
	xtitle("Average number of putts - {it:z} score") ///
	addplot((scatter money_rank z_putts if reg_cat == 3, ///
			legend(order(1 "Low" 2 "Mid" 3 "High" 4 "High data"))))
			

regress money_rank i.reg_cat c.z_putts

regress money_rank i.reg_cat c.z_putts i.reg_cat#c.z_putts, coeflegend
test (_b[2.reg_cat#c.z_putts] = 0) (_b[3.reg_cat#c.z_putts] = 0)

display ((145-5-1)/2)*((0.2818-0.2366)/(1-.2818))

egen z_reg = std(regulation)

regress money_rank c.z_reg c.z_putts c.z_reg#c.z_putts

quietly margins, at(z_putts = (-2(1)2) z_reg = (-1(1)1))
marginsplot, noci scheme(lean2) ///
	legend(pos(6) row(1)) ///
	legend(subtitle("Greens in regulation category")) ///
	title("") ytitle("Predicted money rank") ///
	xtitle("Average number of putts - {it:z} score") ///
	addplot((scatter money_rank z_putts, ///
	    legend(order(1 "-1 SD" 2 "Mean" 3 "1 SD" 4 "Data"))))



regress money_rank i.reg_cat c.z_putts
regress money_rank i.reg_cat c.z_putts i.reg_cat#c.z_putts
display "F_0 = " ((145-5-1)/2)*((0.2818-0.2366)/(1-.2818))
display "p-value = "  1 - F(2, 139, 4.37)
regress money_rank c.z_reg c.z_putts c.z_reg#c.z_putts

margins, at(z_putts = (-2(.5)2) z_reg = (-2(.5)2)) saving(predictions, replace)

clear all
use predictions

rename _at1 z_putts
rename _at2 z_reg
rename _margin pr_money

twoway contour pr_money z_putts z_reg, ccuts(0(10)150)

