clear all
set more off
set linesize 80

drop _all
set seed 49833
set obs 1006
generate educ = floor((20 - 1 + 1)*runiform() + 1)
quietly summarize educ
generate educ_c = educ - r(mean)
generate attitude = 2.5 + 0.04*educ_c + rnormal(0, 0.5)

regress attitude educ_c

	*** http://blog.stata.com/2012/07/18/using-statas-random-number-generators-part-1/
*use "gss_attitude", clear

capture program drop simsample

program define simsample, rclass
	version 15.1
	syntax [, obs(integer 1)]
	drop _all
	set obs `obs'
	generate educ = floor((20 - 1 + 1)*runiform() + 1)
	quietly summarize educ
	generate educ_c = educ - r(mean)
	generate exp_att = 2.5 + 0.04*educ_c
	generate att = rnormal(exp_att, 0.5)
	regress att educ_c
	return scalar b0 = _b[_cons]
	return scalar b1 = _b[educ_c]
	return scalar se_b0 = _se[_cons]
	return scalar se_b1 = _se[educ_c]
	return scalar ul_b1 = _b[educ_c] + _se[educ_c]*invttail(e(df_r), 0.025)
	return scalar ll_b1 = _b[educ_c] - _se[educ_c]*invttail(e(df_r), 0.025)
end

simulate b0 = r(b0) b1 = r(b1) se_b0 = r(se_b0) se_b1 = r(se_b1) ///
		 ul_b1 = r(ul_b1) ll_b1 = r(ll_b1), ///
		 reps(2000) seed(39744) nodots: simsample, obs(1006)

histogram b1, scheme(lean2) xtitle("b1")

summarize b1

simulate b0 = r(b0) b1 = r(b1) se_b0 = r(se_b0) se_b1 = r(se_b1) ///
		 ul_b1 = r(ul_b1) ll_b1 = r(ll_b1), ///
		 reps(2000) seed(39744) nodots: simsample, obs(30)

summarize b1

histogram b1, scheme(lean2) xtitle("b1")

generate cover = ul_b1 >= 0.04 & ll_b1 <= 0.04
tabulate cover

generate simrep = _n
twoway rcap ul_b1 ll_b1 simrep in 1/100 if cover == 0, lcolor(gs8) || ///
	   rcap ul_b1 ll_b1 simrep in 1/100 if cover == 1, lcolor(black) || ///
	   scatter b1 simrep in 1/100 if cover == 0, msymbol(diamond) mcolor(gs8) || ///
	   scatter b1 simrep in 1/100 if cover == 1, msymbol(circle) mcolor(black) ///
	   scheme(lean2) legend(off) yline(0.04)
