clear all
set more off

twoway function y = ntden(38, 1.58, x), range(2.02 6) ///
					color(gs12) recast(area)  || ///
	   function y = tden(38, x), range(-3 3) ///
					droplines(0) || ///
	   function y = ntden(38, 1.58, x), range(-3 6) ///
					lstyle(foreground) droplines(1.58) || ///
	   pci .4 2.02 0 2.02, lwidth(thick) || ///
	   pci .4 -2.02 0 -2.02, lwidth(thick) || ///
	   pcarrowi .04 -3 .02 -2.02 (12) "Critical Value" ///
			   .04 1.25 .02 2.02 (12) "Critical Value" ///
			   .20 5 .17 2.75 (12) "Power" /// 
			   .20 5 .10 3.0 (12) "" ///
			   .42 -1 .35 0 (9) "{&delta} = {&mu}{subscript:1} - {&mu}{subscript:2} = 0 " ///
			   .42 2.58 .35 1.58 (3) "{&delta} = {&mu}{subscript:1} - {&mu}{subscript:2} = 0.5 " , ///
					text(.42 1.58 "Alternative") ///
					text(.42 0 "Null") ///
					yscale(range(0 .45)) ylab(,nogrid) ///
					xtitle("{it:t}") ///
	      scheme(lean2) legend(off)



capture program drop simpower

program define simpower, rclass
	version 14.1
	syntax [, m1(real 0) m2(real 0) ///
	sd1(real 1) sd2(real 2) ///
	n1(integer 1) n2(integer 1)]
	drop _all
	local obs = max(`n1', `n2')
	set obs `obs'
	gen y1 = rnormal(`m1', `sd1') in 1/`n1'
	gen y2 = rnormal(`m2', `sd2') in 1/`n2'
	ttest y1==y2, unpaired
	return scalar delta = `m1' - `m2'
	return scalar m1 = r(mu_1)
	return scalar m2 = r(mu_2)
	return scalar sd1 = r(sd_1)
	return scalar sd2 = r(sd_2)
	return scalar n1 = r(N_1)
	return scalar n2 = r(N_2)
	return scalar t = r(t)
	return scalar df = r(df_t)
	return scalar p = r(p)
end

simulate m1 = r(m1) m2 = r(m2) sd1 = r(sd1) sd2 = r(sd2) ///
		 n1 = r(n1) n2 = r(n2) t = r(t) df = r(df) p = r(p) ///
		 delta = r(delta), reps(1000) seed(43714) nodots: simpower, ///
		 m1(0) m2(0) sd1(1) sd2(1) n1(20) n2(20)

display invt(38, .975)
gen reject = t > 2.02 | t < -2.02 
tabulate reject

twoway histogram t, fcolor(gs15) || ///
	   function y = tden(38, x), range(-4 4) ///
	   lstyle(foreground) dropline(0) || ///
	   pci .075 2.02 0 2.02, lwidth(thick) || ///
	   pci .075 -2.02 0 -2.02, lwidth(thick) ///
	   scheme(lean2) legend(off) yscale(range(0 .52) off) ///
	   ylab(, nogrid) xtitle("{it:t}")
	   

simulate m1 = r(m1) m2 = r(m2) sd1 = r(sd1) sd2 = r(sd2) ///
		 n1 = r(n1) n2 = r(n2) t = r(t) df = r(df) p = r(p) ///
		 delta = r(delta), reps(1000) seed(438854) nodots: simpower, ///
		 m1(.5) m2(0) sd1(1) sd2(1) n1(20) n2(20)


twoway histogram t, fcolor(gs15) || ///
	   function y = tden(38, x), range(-4 4) ///
	   lstyle(foreground) dropline(0) || ///
	   function y = ntden(38, 1.58, x), range(-4 6) ///
	   lstyle(foreground) dropline(1.58) || ///
	   pci .4 2.02 0 2.02, lwidth(thick) || ///
	   pci .4 -2.02 0 -2.02, lwidth(thick) ///
	   scheme(lean2) legend(off) yscale(range(0 .52) off) ///
	   text(.45 1.58 "Alternative") ///
	   text(.45 0 "Null")  ///
	   ylab(, nogrid) xtitle("{it:t}")
	   

gen reject_alt = t > 2.02 | t < -2.02 
tabulate reject_alt


simulate m1 = r(m1) m2 = r(m2) sd1 = r(sd1) sd2 = r(sd2) ///
		 n1 = r(n1) n2 = r(n2) t = r(t) df = r(df) p = r(p) ///
		 delta = r(delta), reps(1000) seed(438854) nodots: simpower, ///
		 m1(.5) m2(0) sd1(1) sd2(1) n1(50) n2(50)

twoway histogram t, fcolor(gs15) || ///
	   function y = tden(98, x), range(-4 4) ///
	   lstyle(foreground) dropline(0) || ///
	   function y = ntden(98, 2.5, x), range(-4 6) ///
	   lstyle(foreground) dropline(2.5) || ///
	   pci .4 1.98 0 1.98, lwidth(thick) || ///
	   pci .4 -1.98 0 -1.98, lwidth(thick) ///
	   scheme(lean2) legend(off) yscale(range(0 .52) off) ///
	   text(.45 2.5 "Alternative") ///
	   text(.45 0 "Null")  ///
	   ylab(, nogrid) xtitle("{it:t}")
	   

gen reject_alt_n50 = t > 1.98 | t < -1.98 
tabulate reject_alt_n50


gen sig = p < 0.05
tabulate sig

local sd1 = 1
local sd2 = 1
local m1 = .5
local m2 = 0
local n1 = 50
local n2 = 50
local df1 = `n1' + `n2' - 2
local crit1 = invt(`df1', .975)
display `crit1'
local delta = `m1' - `m2'
local sigd = sqrt((`sd1'^2/`n1') + (`sd2'^2/`n2'))

local t2 = `delta'/`sigd'
display `t2'


#delimit ;

twoway histogram t, fcolor(gs15) bin(20) ||
	   function y = tden(`df1', x), range(-4 4)
					lstyle(foreground) dropline(0) ||
	   function y = ntden(`df1', `t2', x), range(-4 6)
					lstyle(foreground) dropline(`t2') ||
	   pci .4 `crit1' 0 `crit1', lwidth(thick)
			text(.49 `t2' "Alternative")
			text(.45 `t2' "{&mu}{subscript:1} - {&mu}{subscript:2} =")
			text(.42 `t2' "{&delta}{subscript:A} = 0.5") 
			text(.49 0 "Null") 
			text(.45 0 "{&mu}{subscript:1} - {&mu}{subscript:2} =")
			text(.42 0 "{&delta}{subscript:0} = 0") 
			scheme(lean2) legend(off)
				yscale(range(0 .52) off) ylab(,nogrid)
				xtitle("{it:t}");
#delimit cr	


				

simulate m1 = r(m1) m2 = r(m2) sd1 = r(sd1) sd2 = r(sd2) ///
		 n1 = r(n1) n2 = r(n2) t = r(t) df = r(df) p = r(p) ///
		 delta = r(delta), reps(1000) seed(438854) nodots: simpower, ///
		 m1(.5) m2(0) sd1(1) sd2(1) n1(50) n2(50)

gen sig = p < 0.05
tabulate sig
			
local sd1 = 1
local sd2 = 1
local m1 = .5
local m2 = 0
local n1 = 50
local n2 = 50
local df1 = `n1' + `n2' - 2
local crit1 = invt(`df1', .975)
local delta = `m1' - `m2'
local sigd = sqrt((`sd1'^2/`n1') + (`sd2'^2/`n2'))

local t2 = `delta'/`sigd'


#delimit ;

twoway histogram t, fcolor(gs15) ||
	   function y = tden(`df1', x), range(-4 4)
					lstyle(foreground) dropline(0) ||
	   function y = ntden(`df1', `t2', x), range(-4 6)
					lstyle(foreground) dropline(0) ||
	   pci .4 `crit1' 0 `crit1', lwidth(thick)
					text(.49 `t2' "Alternative")
			text(.45 `t2' "{&mu}{subscript:1} - {&mu}{subscript:2} =")
			text(.42 `t2' "{&delta}{subscript:A} = 0.5") 
			text(.49 0 "Null") 
			text(.45 0 "{&mu}{subscript:1} - {&mu}{subscript:2} =")
			text(.42 0 "{&delta}{subscript:0} = 0") 
			scheme(lean2) legend(off)
				yscale(range(0 .52) off) ylab(,nogrid)
				xtitle("{it:t}");
#delimit cr
					
