clear all

use ybocs2
rename sex women

sem (ybocs1 ybocs2 ybocs3 ybocs4 ybocs5), ///
	covstructure(_Ex, unstructured) group(women) ginvariant(none)
estimates store omnibus_free

sem (ybocs1 ybocs2 ybocs3 ybocs4 ybocs5), ///
	covstructure(_Ex, unstructured) group(women) ginvariant(all)	
estimates store omnibus_const

lrtest omnibus_free omnibus_const

sem (OBSESS -> ybocs1 ybocs2 ybocs3 ybocs4 ybocs5), var(OBSESS@1) 
estat gof, stats(all)

capture program drop adjfit

program adjfit, rclass
	syntax namelist(name = namelist id = "SEM Estimation Results Required" max=2 local)
	local res nullchi nulldf modelchi modeldf tli adjcfi
	tempname `res'
	quietly estimates restore `1'
	scalar `nullchi' = e(chi2_ms)
	scalar `nulldf' = e(df_ms)
	quietly estimates restore `2'
	scalar `modelchi' = e(chi2_ms)
	scalar `modeldf' = e(df_ms)
	scalar `adjcfi' = 1 - ((`modelchi' - `modeldf')/(max(`nullchi' - `nulldf', `modelchi' - `modeldf')))
	return scalar adjcfi = `adjcfi'
	display "The null model is `1'"
	display "The proposed model is `2'"
	display "The Adjusted CFI is " round(`adjcfi', 0.001)
end

// null model ala Widaman and Thompson
sem (0: ybocs1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: ybocs1 ybocs2 ybocs3 ybocs4 ybocs5), ///
	group(women) ginvariant(meanex covex) ///
	covstruct(_OEx, diagonal) nolog
estimates store null

// configural

sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) /// 
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(0: ybocs1 <- _cons@i1) ///
	(1: ybocs1 <- _cons@i1), ///
	group(women) ginvariant(none) ///
	var(0: OBSESS@1) var(1:OBSESS@var) means(0:OBSESS@0) means(1:OBSESS@mean) ///
	nolog nocnsreport 
estimates store configural
adjfit null configural 
estadd scalar adjcfi = r(adjcfi)

adjfit null configural 

// metric -- weak invariance	
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) /// 
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(0: ybocs1 <- _cons@i1) ///
	(1: ybocs1 <- _cons@i1), ///
	group(women) ginvariant(mcoef) ///
	var(0: OBSESS@1) var(1:OBSESS@var) means(0:OBSESS@0) means(1:OBSESS@mean)
estimates store metric
estadd lrtest configural
adjfit null metric
estadd scalar adjcfi = r(adjcfi)

// scalar -- strong invariance

sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5), ///
		group(women) ginvariant(mcoef mcons) ///
		var(0: OBSESS@1) var(1:OBSESS@var) means(0:OBSESS@0) means(1:OBSESS@mean)
estimates store scalar	
estadd lrtest metric	
adjfit null scalar
estadd scalar adjcfi = r(adjcfi)	
		
// residual -- strict invariance		
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5), ///
		group(women) ginvariant(mcoef mcons merrvar) ///
		var(0: OBSESS@1) var(1:OBSESS@var) means(0:OBSESS@0) means(1:OBSESS@mean)
estimates store residual
estadd lrtest scalar
adjfit null residual
estadd scalar adjcfi = r(adjcfi)
		
// structural -- variance		
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5), ///
		group(women) ginvariant(mcoef mcons merrvar) ///
		var(0: OBSESS@1) var(1:OBSESS@1) means(0:OBSESS@0) means(1:OBSESS@mean)
estimates store struct_var
estadd lrtest residual
adjfit null struct_var
estadd scalar adjcfi = r(adjcfi)
		
// structural -- mean and variance 		
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5), ///
		group(women) ginvariant(mcoef mcons merrvar) ///
		var(0: OBSESS@1) var(1:OBSESS@1) means(0:OBSESS@0) means(1:OBSESS@0) coeflegend
estimates store struct_mean_var
estadd lrtest struct_var
adjfit null struct_mean_var
estadd scalar adjcfi = r(adjcfi)


lrtest configural metric 
lrtest metric scalar
lrtest scalar residual
lrtest residual struct_var
lrtest struct_var struct_mean_var






esttab configural metric scalar residual strict_var strict_mean_variance, ///
	   varwidth(16) b(2) stats(N chi2_ms df_ms cfi rmsea srmr) ///
	not nostar varlabels(0.women#c.OBSESS   "lambda_m") ///
	title(YBOCS Measurement Invariance Results) ///
	addnote("Note. YBOCS = Yale-Brown Obssessive Compulsive Scale; The first two coefficients" "for every outcome are the loadings and the second two are intercepts.") ///
	mtitles("Configural" "Metric" "Scalar" "Residual" "Variance" "Mean") 
*/	
	
esttab configural metric scalar residual struct_var struct_mean_var ///
	   using "invar_table.tex", ///
	   longtable booktabs alignment(D{.}{.}{-1}) ///
	varwidth(20) b(2) stats(N lrtest_chi2 lrtest_df lrtest_p adjcfi, ///
							labels("\$N$" "\$\chi^2_{diff}$" "\$df$" "\$p$" "Adj. CFI") ///
							fmt(0 2 0 2 3)) ///
	substitute(\_ _) ///
	not nostar nonumbers	///
	varlabels(0.women#c.OBSESS "\$\lambda_{men}$" ///
			  1.women#c.OBSESS "\$\lambda_{women}$" ///
			  ybocs1:0.women "\$\tau_{men}$" /// 
			  ybocs2:0.women "\$\tau_{men}$" /// 
			  ybocs3:0.women "\$\tau_{men}$" /// 
			  ybocs4:0.women "\$\tau_{men}$" /// 
			  ybocs5:0.women "\$\tau_{men}$" /// 
			  ybocs1:1.women "\$\tau_{women}$" /// 
			  ybocs2:1.women "\$\tau_{women}$" /// 
			  ybocs3:1.women "\$\tau_{women}$" /// 
			  ybocs4:1.women "\$\tau_{women}$" /// 
			  ybocs5:1.women "\$\tau_{women}$" ///
			  var(e.ybocs1)#0.women "\$\theta_{1men}$"   ///
			  var(e.ybocs2)#0.women "\$\theta_{2men}$"   ///
			  var(e.ybocs3)#0.women "\$\theta_{3men}$"   ///
			  var(e.ybocs4)#0.women "\$\theta_{4men}$"   ///
			  var(e.ybocs5)#0.women "\$\theta_{5men}$"   ///
			  var(e.ybocs1)#1.women "\$\theta_{1women}$" ///
			  var(e.ybocs2)#1.women "\$\theta_{2women}$" ///
			  var(e.ybocs3)#1.women "\$\theta_{3women}$" ///
			  var(e.ybocs4)#1.women "\$\theta_{4women}$" ///
			  var(e.ybocs5)#1.women "\$\theta_{5women}$" ///
			  mean(OBSESS)#0.women "\$\kappa_{men}$" ///
			  mean(OBSESS)#1.women "\$\kappa_{women}$" ///
			  var(OBSESS)#0.women "\$\phi_{men}$" ///
			  var(OBSESS)#1.women "\$\phi_{women}$") ///
	order(ybocs1: ybocs2: ybocs3: ybocs4: ybocs5: ///
			var(e.ybocs1)#0.women ///
			var(e.ybocs1)#1.women ///
			var(e.ybocs2)#0.women ///
			var(e.ybocs2)#1.women ///
			var(e.ybocs3)#0.women ///
			var(e.ybocs3)#1.women ///
			var(e.ybocs4)#0.women ///
			var(e.ybocs4)#1.women ///
			var(e.ybocs5)#0.women ///
			var(e.ybocs5)#1.women ///
			mean(OBSESS)#0.women ///
			mean(OBSESS)#1.women ///
			var(OBSESS)#0.women ///
			var(OBSESS)#1.women) ///
	eqlabels("YBOCS1" "YBOCS2" "YBOCS3" "YBOCS4" "YBOCS5" "Residuals,\\ Latent Mean, and\\ Latent Variance") ///
	title(YBOCS Measurement Invariance Results\label{tab:invartab}) ///
	addnote("Note. YBOCS = Yale-Brown Obsessive Compulsive Scale; The first two coefficients" "for every outcome are the loadings and the second two are intercepts.") ///
	mtitles("Configural" "Metric" "Scalar" "Residual" "Variance" "Mean") replace

	


sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(0: OBSESS -> oci_tot@reg0) ///
	(1: OBSESS -> oci_tot@reg1), ///
		group(women) ginvariant(mcoef mcons merrvar) ///
		var(0: OBSESS@1) var(1:OBSESS@1) means(0:OBSESS@0) means(1:OBSESS@0)
estimates store regfree
		
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(0: OBSESS -> oci_tot@reg) ///
	(1: OBSESS -> oci_tot@reg), ///
		group(women) ginvariant(mcoef mcons merrvar) ///
		var(0: OBSESS@1) var(1:OBSESS@1) means(0:OBSESS@0) means(1:OBSESS@0)
estimates store regconst

lrtest regfree regconst

** ybocs1 <- _cons@0

/*
sem (0: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(1: OBSESS -> ybocs1@l1 ybocs2 ybocs3 ybocs4 ybocs5) ///
	(0: ybocs1 <- _cons@m2) (1: ybocs1 <- _cons@m3) , ///
		group(women) ginvariant(mcoef mcons) ///
		var(0: OBSESS@1) var(1:OBSESS@var) means(0:OBSESS@0) means(1:OBSESS@0)
*/

